import { useEffect, useState } from 'react';

interface CountdownBarProps {
  remainingTime: number;
  period: number;
}

export function CountdownBar({ remainingTime, period }: CountdownBarProps) {
  const [progress, setProgress] = useState(0);

  useEffect(() => {
    // Reset progress when a new period starts
    if (remainingTime === period) {
      setProgress(100);
    }
    
    const percentage = (remainingTime / period) * 100;
    
    // Use a timeout to smooth the transition
    const timer = setTimeout(() => setProgress(percentage), 50);

    return () => clearTimeout(timer);
  }, [remainingTime, period]);

  return (
    <div className="w-full bg-slate-200 dark:bg-slate-700 rounded-full h-1.5">
      <div
        className="bg-black h-1.5 rounded-full transition-all duration-1000 ease-linear"
        style={{ width: `${progress}%` }}
      ></div>
    </div>
  );
}
