import type { TotpAccount } from '../services/db';
import { TotpCard } from './TotpCard';

interface TotpListProps {
  accounts: TotpAccount[];
  onAccountDeleted: (id: number) => void;
}

export function TotpList({ accounts, onAccountDeleted }: TotpListProps) {
  if (accounts.length === 0) {
    return (
      <div className="text-center py-20 px-4 bg-white dark:bg-slate-900 rounded-lg shadow-fluent-md">
        <h3 className="text-lg font-medium text-slate-900 dark:text-white">No Accounts Yet</h3>
        <p className="text-slate-500 dark:text-slate-400 mt-1">
          Click on "Add Account" in the navigation bar to get started.
        </p>
      </div>
    );
  }

  return (
    <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">
      {accounts.map((account) => (
        <TotpCard key={account.id} account={account} onDelete={onAccountDeleted} />
      ))}
    </div>
  );
}
