import { useState, useEffect } from 'react';
import { getAllAccounts, type TotpAccount } from '../services/db';

export function useAccounts() {
  const [accounts, setAccounts] = useState<TotpAccount[]>([]);
  const [loading, setLoading] = useState<boolean>(true);
  const [error, setError] = useState<Error | null>(null);

  useEffect(() => {
    async function fetchAccounts() {
      try {
        setLoading(true);
        const data = await getAllAccounts();
        setAccounts(data);
      } catch (err) {
        setError(err instanceof Error ? err : new Error('Failed to fetch accounts'));
      } finally {
        setLoading(false);
      }
    }

    fetchAccounts();
  }, []);

  return { accounts, setAccounts, loading, error };
}
