import { useState, useEffect } from 'react';
import * as OTPAuth from 'otpauth';
import type { TotpAccount } from '../services/db';

export function useTotp(account: TotpAccount) {
  const [totp, setTotp] = useState('');
  const [remainingTime, setRemainingTime] = useState(0);

  useEffect(() => {
    if (!account.secret) {
      setTotp('Error');
      setRemainingTime(0);
      return;
    }

    const totpAuth = new OTPAuth.TOTP({
      issuer: account.issuer,
      label: account.name,
      algorithm: account.algorithm,
      digits: account.digits,
      period: account.period,
      secret: OTPAuth.Secret.fromBase32(account.secret),
    });

    const updateTotp = () => {
      try {
        const token = totpAuth.generate();
        setTotp(token);
        const nextUpdate = (totpAuth.period - (Math.floor(Date.now() / 1000) % totpAuth.period)) * 1000;
        setRemainingTime(Math.ceil(nextUpdate / 1000));
      } catch (error) {
        console.error('Error generating TOTP:', error);
        setTotp('Error');
        setRemainingTime(0);
      }
    };

    updateTotp();
    const interval = setInterval(updateTotp, 1000);

    return () => clearInterval(interval);
  }, [account]);

  return { totp, remainingTime };
}
