import { useAccounts } from '../hooks/useAccounts';
import { TotpList } from '../components/TotpList';

export default function HomePage() {
  const { accounts, setAccounts, loading, error } = useAccounts();

  const handleAccountDeleted = (deletedId: number) => {
    setAccounts(currentAccounts => currentAccounts.filter(acc => acc.id !== deletedId));
  };

  if (loading) {
    return <p className="text-center text-slate-500 dark:text-slate-400 py-10">Loading accounts...</p>;
  }

  if (error) {
    return <p className="text-center text-red-500 dark:text-red-400 py-10">Error: {error.message}</p>;
  }

  return (
    <div className="space-y-8">
      <header>
        <h1 className="text-3xl font-bold tracking-tight text-slate-900 dark:text-slate-100">
          Accounts
        </h1>
        <p className="mt-1 text-slate-600 dark:text-slate-400">
          Your Time-based One-Time Passwords.
        </p>
      </header>
      
      <TotpList accounts={accounts} onAccountDeleted={handleAccountDeleted} />
    </div>
  );
}
